pub struct Call<V> {
pub val: V,
pub shared: bool,
}Expand description
The result of a singleflight call.
val is the value produced by the executed function.
shared is true when this caller received a result that was computed
by another caller rather than executing the function itself.
Fields
val: VTrait Implementations
impl<V: Eq> Eq for Call<V>
impl<V> StructuralPartialEq for Call<V>